************************************
Population
************************************

A ``Population`` object represents a group of identical neurons. It is associated with a geometry (defining the number of neurons and optionally its spatial structure), a neuron type and optionally a name.


.. autoclass:: ANNarchy.Population
   :members:

